@@ -86,6 +86,21 @@ class TestAhbExpressionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                "Muss[UB1]U[5]",
+                Tree(
+                    "ahb_expression",
+                    [
+                        Tree(
+                            "single_requirement_indicator_expression",
+                            [
+                                Token("MODAL_MARK", "Muss"),
+                                Token("CONDITION_EXPRESSION", "[UB1]U[5]"),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
             pytest.param(
                 "Kann([1]O[5])U[904]",
                 Tree(
@@ -347,10 +362,10 @@ class TestAhbExpressionParser:
             # marks the characters alone are all ok (lower case 'u' is a valid expression operator and lower case 's'
             # could be interpreted as lower case model mark). As of 2021-10-27, when parsing an AHB expression we only
             # use a simple regex to roughly check if the characters at the positions where we expect condition
-            # expressions to be found are allow listed. But we do not check the grammar yet. The grammar is checked
+            # expressions to be found are allow-listed. But we do not check the grammar yet. The grammar is checked
             # upon parsing the condition expression, but that's the second step. To keep the test failing, I introduced
             # a negative look ahead where formerly only a "character set" allow list check.
-            pytest.param("Muss[2]B[3]"),
+            pytest.param("Muss[2]C[3]"),
         ],
     )
     def test_parse_invalid_ahb_expression(self, ahb_expression: str):
