@@ -1,12 +1,11 @@
 """ Test for the requirement constraint evaluation of the condition expressions. """
 
-from unittest.mock import AsyncMock
-
 import inject
 import pytest  # type:ignore[import]
 import pytest_asyncio  # type:ignore[import]
 
-from ahbicht.content_evaluation.rc_evaluators import RcEvaluator
+from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableDataProvider
+from ahbicht.content_evaluation.token_logic_provider import SingletonTokenLogicProvider, TokenLogicProvider
 from ahbicht.evaluation_results import RequirementConstraintEvaluationResult
 from ahbicht.expressions.condition_nodes import (
     ConditionFulfilledValue,
@@ -15,8 +14,12 @@ from ahbicht.expressions.condition_nodes import (
     RequirementConstraint,
     UnevaluatedFormatConstraint,
 )
-from ahbicht.expressions.hints_provider import HintsProvider
 from ahbicht.expressions.requirement_constraint_expression_evaluation import requirement_constraint_evaluation
+from unittests.defaults import (
+    empty_default_hints_provider,
+    empty_default_rc_evaluator,
+    return_empty_dummy_evaluatable_data,
+)
 
 
 class TestRequirementConstraintEvaluation:
@@ -37,10 +40,12 @@ class TestRequirementConstraintEvaluation:
     @pytest_asyncio.fixture()
     def setup_and_teardown_injector(self):
         inject.clear_and_configure(
-            lambda binder: binder.bind(HintsProvider, AsyncMock(wraps=HintsProvider)).bind(
-                RcEvaluator, AsyncMock(wraps=RcEvaluator)
-            )
+            lambda binder: binder.bind(
+                TokenLogicProvider,
+                SingletonTokenLogicProvider([empty_default_hints_provider, empty_default_rc_evaluator]),
+            ).bind_to_provider(EvaluatableDataProvider, return_empty_dummy_evaluatable_data),
         )
+
         yield
         inject.clear()
 
